@@ -6,10 +6,11 @@ from samtranslator.model.intrinsics import ref, fnGetAtt
 class IAMRole(Resource):
     resource_type = 'AWS::IAM::Role'
     property_types = {
-            'AssumeRolePolicyDocument': PropertyType(True, is_type(dict)),
-            'ManagedPolicyArns': PropertyType(False, is_type(list)),
-            'Path': PropertyType(False, is_str()),
-            'Policies': PropertyType(False, is_type(list))
+        'AssumeRolePolicyDocument': PropertyType(True, is_type(dict)),
+        'ManagedPolicyArns': PropertyType(False, is_type(list)),
+        'Path': PropertyType(False, is_str()),
+        'Policies': PropertyType(False, is_type(list)),
+        'PermissionsBoundary': PropertyType(False, is_str())
     }
 
     runtime_attrs = {
@@ -17,6 +18,7 @@ class IAMRole(Resource):
         "arn": lambda self: fnGetAtt(self.logical_id, "Arn")
     }
 
+
 class IAMRolePolicies():
 
     @classmethod
